<?php
// $Id: nodestream.profile,v 1.1.2.8 2010/08/29 23:02:38 dixon Exp $

/**
 * @file
 * Default minimal installation profile for NodeStream.
 *
 * The different install operations is abtracted into small parts for
 * maintability and reusability for our two co-existing profiles.
 * Performance-wise this isn't optimal, but that isn't critical during the
 * install process.
 */

/**
 * Implementation of hook_profile_details().
 */
function nodestream_profile_details() {
  return array(
    'name' => 'NodeStream',
    'description' => 'Default installation profile for NodeStream with some pre generated content.',
  );
}

/**
 * Implementation of hook_profile_task_list().
 */
function nodestream_profile_task_list() {
  global $conf;
  $conf['site_name'] = 'NodeStream installation guide';
  $conf['site_footer'] = 'NodeStream by <a href="http://nodeone.se">NodeOne</a>';
  return array();
}

/**
 * Implementation of hook_profile_modules().
 */
function nodestream_profile_modules() {
  $core = array(
    'dblog',
    'help',
    'menu',
    'path',
    'poll',
    'taxonomy',
    'upload',
  );
  $contrib = array(
    'ad',
    'admin',
    'chart',
    'conditional_fields',
    'content',
    'ctools',
    'devel',
    'diff',
    'disqus',
    'draggableviews',
    'draggableviews_cck',
    'dynamic_emfield',
    'dynamic_filefield',
    'dynamic_formatters',
    'email',
    'emfield',
    'emimage',
    'emvideo',
    'emthumb',
    'features',
    'filefield',
    'geotaxonomy',
    'imageapi',
    'imageapi_gd',
    'imagecache',
    'imagecache_ui',
    'imagefield',
    'jquery_update',
    'nodereference',
    'openlayers',
    'openlayers_cck',
    'openlayers_views',
    'openlayers_ui',
    'optionwidgets',
    'page_manager',
    'panels',
    'panels_everywhere',
    'panels_mini',
    'pathauto',
    'text',
    'token',
    'twitter',
    'scheduler',
    'semanticviews',
    'strongarm',
    'vertical_tabs',
    'views',
    'views_content',
    'views_slideshow',
    'views_slideshow_singleframe',
    'views_ui',
    'webform',
  );
  $nodestream = array(
    'ns_article',
    'ns_blog',
    'ns_contributor',
    'ns_core',
    'ns_fact',
    'ns_form',
    'ns_image',
    'ns_layout',
    'ns_location',
    'ns_page',
    'ns_poll',
    'ns_video',
  );

  // Check to see if the third party library 'jquery.ui' is available before
  // installing dependant modules. The packaging system on drupal.org can't
  // include it because of it's policy regarding third party sources.
  //
  // If this profile was compiled by the drupal.org system all modules will be
  // located in 'profiles/nodestream/modules/' but if the profile was compiled
  // by hand all modules will be located in 'sites/all/modules/'.
  $paths = array(
    'profiles/nodestream/modules',
    'sites/all/modules',
  );
  foreach ($paths as $path) {
    // The file 'version.txt' indicates that the library is in place.
    if (file_scan_directory($path . '/jquery_ui', 'version.txt')) {
      $contrib[] = 'jquery_ui';
      $contrib[] = 'modalframe';
      $contrib[] = 'noderelationships';
    }
  }

  return array_merge($core, $contrib, $nodestream);
}

/**
 * Helper function for fetching the order of demo content files.
 */
function nodestream_profile_content_types() {
  return array(
    'contributor',
    'video',
    'image',
    'fact',
    'article',
    'promo',
    'blog',
    'post',
    'ad',
  );
}

/**
 * Helper function for fetching the order of menu files.
 */
function nodestream_profile_menu_names() {
  return array(
    'primary-links',
    'secondary-links',
  );
}

/**
 * Implementation of hook_profile_tasks().
 */
function nodestream_profile_tasks(&$task, $url) {
  $batch = array();

  if ($task == 'profile') {
    $batch = nodestream_profile_batch_get();
  }
  return nodestream_profile_batch_process($task, $url, $batch);
}

/**
 * Returns the default batch.
 *
 * @todo Currently the addition of the demo content requires internet
 *   connection. Check for a working connection before assembling the install
 *   operations with demo content.
 */
function nodestream_profile_batch_get() {
  $batch = array();
  $batch['title'] = st('Configuring !drupal', array('!drupal' => drupal_install_profile_name()));
  $batch['error_message'] = st('There was an error configuring !drupal.', array('!drupal' => drupal_install_profile_name()));
  $batch['operations'][] = array('nodestream_profile_operation_prepare', array());
  $batch['operations'][] = array('nodestream_profile_operation_basic', array());
  $batch['operations'][] = array('nodestream_profile_operation_social', array());
  $batch['operations'][] = array('nodestream_profile_operation_vocabulary', array());
  $batch['operations'][] = array('nodestream_profile_operation_term', array('required'));
  $batch['operations'][] = array('nodestream_profile_operation_term', array('demo'));
  foreach (nodestream_profile_content_types() as $type) {
    $batch['operations'][] = array('nodestream_profile_operation_content', array($type));
  }
  foreach (nodestream_profile_menu_names() as $menu_name) {
    $batch['operations'][] = array('nodestream_profile_operation_menu', array($menu_name, 'required'));
    $batch['operations'][] = array('nodestream_profile_operation_menu', array($menu_name, 'demo'));
  }
  $batch['finished'] = 'nodestream_profile_operation_finished';
  return $batch;
}

/**
 * Processes the batch.
 */
function nodestream_profile_batch_process($task, $url, $batch = array()) {
  if ($task == 'profile') {
    variable_set('install_task', 'ns-batch');
    batch_set($batch);
    batch_process($url, $url);
    // Jut for CLI installs.
    return;
  }
  // We are running a batch task for this profile so do nothing and return page.
  if ($task == 'ns-batch') {
    include_once 'includes/batch.inc';
    $output = _batch_page();
  }
  return $output;
}

/**
 * Preparing install operation.
 */
function nodestream_profile_operation_prepare(&$context) {
  $context['message'] = t('Preparing configuration.');
  drupal_flush_all_caches();
}

/**
 * Install operation for basic stuff.
 */
function nodestream_profile_operation_basic(&$context) {
  $context['message'] = t('Setting up basic features.');

  // Configure the Pathauto module.
  variable_set('pathauto_node_pattern', '');
  variable_set('pathauto_taxonomy_pattern', '');
  variable_set('pathauto_user_pattern', '');

  // Site front page.
  variable_set('site_frontpage', 'taxonomy/term/1');

  // Configure the Geo Taxonomy module.
  variable_set('geotaxonomy_3', TRUE);

  // Configure the Advertisement module.
  variable_set('ad_group_vid', 4);
  variable_set('ad_display', 'raw');

  // Remove all blocks.
  db_query("TRUNCATE {blocks}");

  // Only admin users can create new user accounts on the site.
  variable_set('user_register', 0);

  // Configure date formats.
  variable_set('configurable_timezones', 0);
  variable_set('date_first_day', 1);
  variable_set('date_format_short', 'Y-m-d H:i');
  variable_set('date_format_short_custom', 'Y-m-d H:i');
  variable_set('date_format_medium', 'D, Y-m-d H:i');
  variable_set('date_format_medium_custom', 'D, Y-m-d H:i');
  variable_set('date_format_long', 'l, j F, Y - H:i');
  variable_set('date_format_long_custom', 'l, j F, Y - H:i');

  // Configure the Scheduler module.
  variable_set('scheduler_date_format', 'Y-m-d H:i');

  // Theme related stuff.
  variable_set('theme_default', 'stream');
  variable_set('admin_theme', 'seven');
  variable_set('node_admin_theme', 1);

  // Configure the Admin toolbar.
  variable_set(
    'admin_toolbar',
    array(
      'layout' => 'vertical',
      'position' => 'nw',
      'blocks' => array(
        'admin-create' => -1,
        'admin-menu' => 1,
        'admin-devel' => -1,
        'ns_core-admin_panes' => -1,
      ),
    )
  );

  // Configure the Conditional Fields module.
  conditional_fields_insert_field('ns_image', 'field_ns_image_url', 'field_ns_image_type', array('embed' => 'embed'));
  conditional_fields_insert_field('ns_image', 'field_ns_image_file', 'field_ns_image_type', array('local' => 'local'));

  // Configure the Node Relationships module if requirements was met and it was
  // installed.
  if (module_exists('noderelationships')) {
    module_load_include('inc', 'noderelationships', 'noderelationships');
    noderelationships_settings_save(
      'ns_article',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_article_attachment' => 'noderelationships_noderef:page_grid',
            'field_ns_article_byline' => 'noderelationships_noderef:page_grid',
            'field_ns_article_image' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_article_attachment' => 'field_ns_article_attachment',
            'field_ns_article_byline' => 'field_ns_article_byline',
            'field_ns_article_image' => 'field_ns_article_image',
          ),
          'edit_reference' => array(
            'field_ns_article_attachment' => 'field_ns_article_attachment',
            'field_ns_article_byline' => 'field_ns_article_byline',
            'field_ns_article_image' => 'field_ns_article_image',
          ),
        ),
      )
    );
    noderelationships_settings_save(
      'ns_blog',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_blog_blogger' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_blog_blogger' => 'field_ns_blog_blogger',
          ),
          'edit_reference' => array(
            'field_ns_blog_blogger' => 'field_ns_blog_blogger',
          ),
        ),
      )
    );
    noderelationships_settings_save(
      'ns_image',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_image_credit' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_image_credit' => 'field_ns_image_credit',
          ),
          'edit_reference' => array(
            'field_ns_image_credit' => 'field_ns_image_credit',
          ),
        ),
      )
    );
    noderelationships_settings_save(
      'ns_post',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_post_blog' => 'noderelationships_noderef:page_grid',
            'field_ns_post_blogger' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_post_blog' => 'field_ns_post_blog',
            'field_ns_post_blogger' => 'field_ns_post_blogger',
          ),
          'edit_reference' => array(
            'field_ns_post_blog' => 'field_ns_post_blog',
            'field_ns_post_blogger' => 'field_ns_post_blogger',
          ),
        ),
      )
    );
    noderelationships_settings_save(
      'ns_promo',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_promo_article' => 'noderelationships_noderef:page_grid',
            'field_ns_promo_image' => 'noderelationships_noderef:page_grid',
            'field_ns_promo_parent' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_promo_article' => 'field_ns_promo_article',
            'field_ns_promo_image' => 'field_ns_promo_image',
            'field_ns_promo_parent' => 'field_ns_promo_parent',
          ),
          'edit_reference' => array(
            'field_ns_promo_article' => 'field_ns_promo_article',
            'field_ns_promo_image' => 'field_ns_promo_image',
            'field_ns_promo_parent' => 'field_ns_promo_parent',
          ),
        ),
      )
    );
    noderelationships_settings_save(
      'ns_video',
      array(
        'noderef' => array(
          'search_and_reference_view' => array(
            'field_ns_video_credit' => 'noderelationships_noderef:page_grid',
          ),
          'create_and_reference' => array(
            'field_ns_video_credit' => 'field_ns_video_credit',
          ),
          'edit_reference' => array(
            'field_ns_video_credit' => 'field_ns_video_credit',
          ),
        ),
      )
    );
  }

  // Delete the default webform content type.
  node_type_delete('webform');

  // Enable some page panels.
  variable_set('page_manager_term_view_disabled', 0);
  variable_set('page_manager_node_view_disabled', 0);
  variable_set('panels_everywhere_site_template_enabled', 1);
}

/**
 * Install operation for setting up social features.
 */
function nodestream_profile_operation_social(&$context) {
  $context['message'] = t('Setting up social features.');

  // Configure the Emfield module.
  variable_set('emfield_emimage_allow_flickr', 1);
  variable_set('emfield_emimage_allow_imageshack', 1);
  variable_set('emfield_emimage_allow_photobucket', 1);
  variable_set('emfield_emimage_allow_picasa', 1);

  // Configure the Twitter module.
  variable_set('twitter_default_format', '!title !tinyurl');
  variable_set(
    'twitter_types',
    array(
      'ns_article' => 'ns_article',
      'ns_blog' => 0,
      'ns_contributor' => 0,
      'ns_fact' => 0,
      'ns_form' => 0,
      'ns_image' => 0,
      'ns_location' => 0,
      'ns_page' => 0,
      'ns_post' => 'ns_post',
      'ns_promo' => 0,
      'ns_video' => 0,
      'poll' => 0,
    )
  );

  // Configure the Disqus module.
  variable_set('disqus_location', 'block');
  variable_set(
    'disqus_nodetypes',
    array(
      'ns_article' => 'ns_article',
      'ns_blog' => 0,
      'ns_contributor' => 0,
      'ns_fact' => 0,
      'ns_form' => 0,
      'ns_image' => 0,
      'ns_location' => 0,
      'ns_page' => 0,
      'ns_post' => 'ns_post',
      'ns_promo' => 0,
      'ns_video' => 0,
      'poll' => 0,
    )
  );
}

/**
 * Install operation for setting up the default vocabulary.
 */
function nodestream_profile_operation_vocabulary(&$context) {
  $context['message'] = t('Setting up required vocabularies.');
  $vocabularies = array();

  require_once dirname(__FILE__) . '/taxonomy/vocabulary.inc';

  foreach ($vocabularies as $vocabulary) {
    taxonomy_save_vocabulary($vocabulary);
  }
}

/**
 * Install operation for setting up terms.
 */
function nodestream_profile_operation_term($type, &$context) {
  $context['message'] = t('Setting up !type taxonomy terms.', array('!type' => $type));
  $terms = array();

  require_once dirname(__FILE__) . '/taxonomy/term.' . $type . '.inc';

  foreach ($terms as $term) {
    taxonomy_save_term($term);
  }
}

/**
 * Install operation for setting up demo content.
 */
function nodestream_profile_operation_content($type, &$context) {
  $context['message'] = t('Setting up demo content.');
  $user = user_load(array('uid' => 1));
  $nodes = array();

  require_once dirname(__FILE__) . '/content/' . $type . '.inc';

  foreach ($nodes as $node) {
    $node = (object)$node;
    node_save($node);
  }
}

/**
 * Install operation for setting up menu links.
 */
function nodestream_profile_operation_menu($menu_name, $type, &$context) {
  $context['message'] = t('Setting up !type menu links.', array('!type' => $type));
  $links = array();

  require_once dirname(__FILE__) . '/menu/' . $menu_name . '.' . $type . '.inc';

  foreach ($links as $link) {
    menu_link_save($link);
  }
}

/**
 * Last install operation.
 */
function nodestream_profile_operation_finished($success, $results, $operations) {
  node_access_rebuild();
  variable_set('install_task', 'profile-finished');
}
